using System;
using System.Text;
using System.Collections.Generic;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Com.Benday.InstallerActions;
using System.IO;

/* 
   | Copyright 2007                |
   | Benjamin Day                  |
   | Benjamin Day Consulting, Inc. |
   | http://www.benday.com         |
   | http://blog.benday.com        |
    */

namespace Com.BendayInstallerActions.UnitTests
{
	/// <summary>
	/// Summary description for ConfigFileParserFixture
	/// </summary>
	[TestClass]
	public class ConfigFileParserFixture
	{
		const string KEY_SEARCH_CONFIGURATION = "SEARCH_CONFIGURATION";
		public ConfigFileParserFixture()
		{
			//
			// TODO: Add constructor logic here
			//
		}

		#region Additional test attributes
		//
		// You can use the following additional attributes as you write your tests:
		//
		// Use ClassInitialize to run code before running the first test in the class
		// [ClassInitialize()]
		// public static void MyClassInitialize(TestContext testContext) { }
		//
		// Use ClassCleanup to run code after all tests in a class have run
		// [ClassCleanup()]
		// public static void MyClassCleanup() { }
		//
		// Use TestInitialize to run code before running each test 
		// [TestInitialize()]
		// public void MyTestInitialize() { }
		//
		// Use TestCleanup to run code after each test has run
		// [TestCleanup()]
		// public void MyTestCleanup() { }
		//
		#endregion

		private TestContext m_testContext;
		public TestContext TestContext
		{
			get
			{
				return m_testContext;
			}
			set
			{
				m_testContext = value;
			}
		}

		public string GetTestFilePath(string filename)
		{
			string pathToFilename = Path.Combine(
				String.Format("{0}", this.TestContext.TestDeploymentDir),
				filename);

			string workingCopy = pathToFilename + DateTime.Now.Ticks.ToString();
			File.Copy(pathToFilename, workingCopy);

			return workingCopy;
		}

		[TestMethod]
		public void GetDatabaseConnectionString()
		{

			DatabaseConfigurationParser parser =
				new DatabaseConfigurationParser(GetTestFilePath("test.dataconfiguration.config"));

			Assert.IsNotNull(parser.Server);
			Assert.IsNotNull(parser.UserName);
			Assert.IsNotNull(parser.Password);
			Assert.IsNotNull(parser.Database);
			
			Assert.AreEqual("TheDatabaseServerName", parser.Server, "Server");
			Assert.AreEqual("sa", parser.UserName, "UserName");
			Assert.AreEqual("TheSaPassword", parser.Password, "Password");
			Assert.AreEqual("TheNameOfTheDatabase", parser.Database, "Database");
			Assert.AreEqual(false, parser.UseTrustedConnection, "UseTrustedConnection");
		}

		[TestMethod]
		public void SetDatabaseConnectionString()
		{
			string configFile = "test.dataconfiguration.config";
			configFile = GetTestFilePath(configFile);

			DatabaseConfigurationParser parser =
				new DatabaseConfigurationParser(configFile);

			parser.Server = "server";
			parser.UserName = "username";
			parser.Password = "password";
			parser.Database = "database";
			parser.UseTrustedConnection = false;

			parser.Save();

			parser =
				new DatabaseConfigurationParser(configFile);

			Assert.IsNotNull(parser.Server);
			Assert.IsNotNull(parser.UserName);
			Assert.IsNotNull(parser.Password);
			Assert.IsNotNull(parser.Database);

			Assert.AreEqual("server", parser.Server, "Server");
			Assert.AreEqual("username", parser.UserName, "UserName");
			Assert.AreEqual("password", parser.Password, "Password");
			Assert.AreEqual("database", parser.Database, "Database");
			Assert.AreEqual(false, parser.UseTrustedConnection, "UseTrustedConnection");

			// set server to localhost -- this should automatically change to "(local)"
			parser.Server = "localhost";
			parser.Save();

			parser =
				new DatabaseConfigurationParser(configFile);

			Assert.IsNotNull(parser.Server);
			Assert.AreEqual("(local)", parser.Server, "Server");

			// set to use trusted connection
			parser.UseTrustedConnection = true;
			parser.Server = ".";
			parser.Save();

			parser =
				new DatabaseConfigurationParser(configFile);

			Assert.IsNotNull(parser.Server);
			Assert.IsNull(parser.UserName);
			Assert.IsNull(parser.Password);
			Assert.IsNotNull(parser.Database);

			Assert.AreEqual("(local)", parser.Server, "Server");
			Assert.AreEqual("database", parser.Database, "Database");
			Assert.AreEqual(true, parser.UseTrustedConnection, "UseTrustedConnection");
		}

		[TestMethod]
		public void GetWebConfigAppSettingsValue()
		{
			// "SEARCH_CONFIGURATION"

			string configFile = "test.web.config";
			configFile = GetTestFilePath(configFile);

			WebConfigParser parser =
				new WebConfigParser(configFile);

			Assert.IsNotNull(parser[KEY_SEARCH_CONFIGURATION], "Search config file path.");
			Assert.AreEqual(
				@"C:\dev\Search.config", 
				parser[KEY_SEARCH_CONFIGURATION]);			
		}

		[TestMethod]
		public void GetBogusWebConfigAppSettingsValueReturnsNull()
		{
			// "SEARCH_CONFIGURATION"

			string configFile = "test.web.config";
			configFile = GetTestFilePath(configFile);

			WebConfigParser parser =
				new WebConfigParser(configFile);

			Assert.IsNull(parser["this key does not exist"], "Found bogus value.");
		}

		[TestMethod]
		public void SetWebConfigAppSettingsValue()
		{
			string configFile = "test.web.config";
			configFile = GetTestFilePath(configFile);

			WebConfigParser parser =
				new WebConfigParser(configFile);

			parser[KEY_SEARCH_CONFIGURATION] = "new value";
			parser.Save();

			Assert.IsNotNull(parser[KEY_SEARCH_CONFIGURATION], "Search config file path.");
			Assert.AreEqual(
				"new value",
				parser[KEY_SEARCH_CONFIGURATION]);		
		}

		[TestMethod]
		public void GetHibernateConfigConnectionString()
		{
			HibernateDatabaseConfigurationParser parser =
				new HibernateDatabaseConfigurationParser(GetTestFilePath("test.hibernate.cfg.xml"));

			Assert.IsNotNull(parser.Server);
			Assert.IsNotNull(parser.UserName);
			Assert.IsNotNull(parser.Password);
			Assert.IsNotNull(parser.Database);

			Assert.AreEqual(".", parser.Server, "Server");
			Assert.AreEqual("sa", parser.UserName, "UserName");
			Assert.AreEqual("TheSaPassword", parser.Password, "Password");
			Assert.AreEqual("TestDatabaseName", parser.Database, "Database");
			Assert.AreEqual(false, parser.UseTrustedConnection, "UseTrustedConnection");
		}

		[TestMethod]
		public void SetHibernateConfigDatabaseConnectionString()
		{
			string configFile = "test.hibernate.cfg.xml";
			configFile = GetTestFilePath(configFile);

			HibernateDatabaseConfigurationParser parser =
				new HibernateDatabaseConfigurationParser(configFile);

			parser.Server = "server";
			parser.UserName = "username";
			parser.Password = "password";
			parser.Database = "database";
			parser.UseTrustedConnection = false;

			parser.Save();

			parser =
				new HibernateDatabaseConfigurationParser(configFile);

			Assert.IsNotNull(parser.Server);
			Assert.IsNotNull(parser.UserName);
			Assert.IsNotNull(parser.Password);
			Assert.IsNotNull(parser.Database);

			Assert.AreEqual("server", parser.Server, "Server");
			Assert.AreEqual("username", parser.UserName, "UserName");
			Assert.AreEqual("password", parser.Password, "Password");
			Assert.AreEqual("database", parser.Database, "Database");
			Assert.AreEqual(false, parser.UseTrustedConnection, "UseTrustedConnection");

			parser.UseTrustedConnection = true;
			parser.Save();

			parser =
				new HibernateDatabaseConfigurationParser(configFile);

			Assert.IsNotNull(parser.Server);
			Assert.AreEqual(0, parser.UserName.Length);
			Assert.AreEqual(0, parser.Password.Length);
			Assert.IsNotNull(parser.Database);

			Assert.AreEqual("server", parser.Server, "Server");
			Assert.AreEqual("database", parser.Database, "Database");
			Assert.AreEqual(true, parser.UseTrustedConnection, "UseTrustedConnection");
		}

		[TestMethod]
		public void GetWebConfigConnectionString()
		{
			// "SEARCH_CONFIGURATION"

			string configFile = "test.web.config";
			configFile = GetTestFilePath(configFile);

			WebConfigConnectionStringParser parser =
				new WebConfigConnectionStringParser(configFile, "WebConfigConnectionString");

			Assert.IsNotNull(parser.Server);
			Assert.IsNotNull(parser.UserName);
			Assert.IsNotNull(parser.Password);
			Assert.IsNotNull(parser.Database);

			Assert.AreEqual(".", parser.Server, "Server");
			Assert.AreEqual("sa", parser.UserName, "UserName");
			Assert.AreEqual("TheSaPassword", parser.Password, "Password");
			Assert.AreEqual("TestDatabaseName", parser.Database, "Database");
			Assert.AreEqual(false, parser.UseTrustedConnection, "UseTrustedConnection");
		}

		[TestMethod]
		public void SetWebConfigConnectionString()
		{
			string configFile = "test.web.config";
			configFile = GetTestFilePath(configFile);

			WebConfigConnectionStringParser parser =
				new WebConfigConnectionStringParser(configFile, "WebConfigConnectionString");

			parser.Server = "server";
			parser.UserName = "username";
			parser.Password = "password";
			parser.Database = "database";
			parser.UseTrustedConnection = false;

			parser.Save();

			parser =
				new WebConfigConnectionStringParser(configFile, "WebConfigConnectionString");

			Assert.IsNotNull(parser.Server);
			Assert.IsNotNull(parser.UserName);
			Assert.IsNotNull(parser.Password);
			Assert.IsNotNull(parser.Database);

			Assert.AreEqual("server", parser.Server, "Server");
			Assert.AreEqual("username", parser.UserName, "UserName");
			Assert.AreEqual("password", parser.Password, "Password");
			Assert.AreEqual("database", parser.Database, "Database");
			Assert.AreEqual(false, parser.UseTrustedConnection, "UseTrustedConnection");

		}
	}
}
