using System;
using System.Text;
using System.Collections.Generic;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using System.Collections.Specialized;
using System.DirectoryServices;

/* 
   | Copyright 2007                |
   | Benjamin Day                  |
   | Benjamin Day Consulting, Inc. |
   | http://www.benday.com         |
   | http://blog.benday.com        |
    */

namespace Com.Benday.InstallerActions.UnitTests
{
	/// <summary>
	/// Summary description for IISConfigurationFixture
	/// </summary>
	[TestClass]
	public class IISConfigurationFixture
	{
		public IISConfigurationFixture()
		{
			//
			// TODO: Add constructor logic here
			//
		}

		private TestContext m_testContext;
		public TestContext TestContext
		{
			get
			{
				return m_testContext;
			}
			set
			{
				m_testContext = value;
			}
		}

		[TestMethod]
		public void SecurityConfigTest()
		{
			int result;

			result = IISActiveDirectoryUtility.SecuritySettingAllowAnonymous | IISActiveDirectoryUtility.SecuritySettingAllowNTLM;

			Assert.AreEqual(5, result);
		}

		[TestMethod]
		public void FindIISDirectory()
		{
			string webAppName = "website";

			StringDictionary parameters = new StringDictionary();
			parameters.Add("virtualDirectory", webAppName);


			DirectoryEntry entryForDirectory =
				IISActiveDirectoryUtility.FindVirtualDirectory(parameters);

			Assert.IsNotNull(entryForDirectory, "Could not find it.");
			Assert.AreEqual(webAppName, IISActiveDirectoryUtility.GetName(entryForDirectory), "Not the right directory.");
		}

		[TestMethod]
		public void GetSecuritySettings()
		{
			StringDictionary parameters = new StringDictionary();

			Assert.AreEqual(0, IISActiveDirectoryUtility.GetSecuritySetting(parameters));

			parameters.Add("AllowAnonymous", "0");
			parameters.Add("AllowNTLM", "1");

			Assert.AreEqual(4, IISActiveDirectoryUtility.GetSecuritySetting(parameters));

			parameters["AllowAnonymous"] = "1";
			Assert.AreEqual(5, IISActiveDirectoryUtility.GetSecuritySetting(parameters));
		}

		[TestMethod]
		public void SetSecurity()
		{
			string webAppName = "website";

			StringDictionary parameters = new StringDictionary();
			parameters.Add("virtualDirectory", webAppName);
			parameters.Add("AllowAnonymous", "0");
			parameters.Add("AllowNTLM", "1");

			IISActiveDirectoryUtility.SetSecurity(parameters);

			DirectoryEntry entryForDirectory =
				IISActiveDirectoryUtility.FindVirtualDirectory(parameters);

			object value = entryForDirectory.InvokeGet("AuthFlags");

			Assert.IsNotNull(value, "AuthFlags value was null.");
			Assert.AreEqual("4", value.ToString(), "AuthFlags value was not what was expected.");
		}
	}
}