using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using Com.Benday.Common;

/* 
   | Copyright 2007                |
   | Benjamin Day                  |
   | Benjamin Day Consulting, Inc. |
   | http://www.benday.com         |
   | http://blog.benday.com        |
    */

namespace Com.Benday.InstallerActions
{
	public class DatabaseConfigurationParser : XmlConfigurationParserBase
	{
		public DatabaseConfigurationParser(string path) : base(path)
		{
			NamespaceManager.AddNamespace("default", "http://www.microsoft.com/practices/enterpriselibrary/08-31-2004/data");
			PopulateValuesFromFile();
		}

		private void PopulateValuesFromFile()
		{
			m_database = GetParameterValue("database");
			
			if (Boolean.TryParse(GetParameterValue("Integrated Security"), out m_useTrustedConnection) == false)
			{
				m_useTrustedConnection = false;
			}

			m_server = GetParameterValue("server");
			m_userName = GetParameterValue("user id");
			m_password = GetParameterValue("password");
		}

		private string GetParameterValue(string parameterName)
		{
			XmlElement element = Document.DocumentElement.SelectSingleNode(
				String.Format(
				"//default:parameter[@name='{0}']", parameterName), NamespaceManager) as XmlElement;

			if (element == null)
			{
				return null;
			}
			else if (element.HasAttribute("value") == false)
			{
				return null;
			}
			else
			{
				return element.GetAttribute("value");
			}
		}

		private void SetParameterValue(string parameterName, string parameterValue)
		{
			XmlElement parametersElement = Document.DocumentElement.SelectSingleNode(
				"//default:parameters", NamespaceManager) as XmlElement;

			if (parametersElement == null)
			{
				throw new InvalidOperationException("Could not find parameters node.");
			}

			XmlElement parameterElement = parametersElement.SelectSingleNode(
				String.Format(
				"//default:parameter[@name='{0}']", parameterName), NamespaceManager) as XmlElement;

			if (parameterElement == null)
			{
				parameterElement = Document.CreateElement("parameter");
				parameterElement.SetAttribute("value", parameterValue);
				parametersElement.AppendChild(parameterElement);
			}
			else
			{
				if (parameterValue == null)
				{
					parameterElement.ParentNode.RemoveChild(parameterElement);
				}
				else
				{
					parameterElement.SetAttribute("value", parameterValue);	
				}				
			}
		}

		private string m_server;
		public string Server
		{
			get
			{
				return m_server;
			}
			set
			{
				if (value == "localhost" || value == ".")
				{
					m_server = "(local)";
				}
				else
				{
					m_server = value;	
				}				
			}
		}

		private string m_userName;
		public string UserName
		{
			get
			{
				return m_userName;
			}
			set
			{
				m_userName = value;
			}
		}
		private string m_password;
		public string Password
		{
			get
			{
				return m_password;
			}
			set
			{
				m_password = value;
			}
		}

		private string m_database;
		public string Database
		{
			get
			{
				return m_database;
			}
			set
			{
				m_database = value;
			}
		}

		private bool m_useTrustedConnection;
		public bool UseTrustedConnection
		{
			get
			{
				return m_useTrustedConnection;
			}
			set
			{
				m_useTrustedConnection = value;
			}
		}

		public string ConnectionString
		{
			get
			{
				DbConnectionInfo info = new DbConnectionInfo();

				info.DatabaseType = DatabaseTypeEnum.SqlServer2000;
				
				info.InitialCatalog = this.Database;
				info.ServerName = this.Server;
				info.UserName = this.UserName;
				info.Password = this.Password;
				info.UseIntegratedSecurity = this.UseTrustedConnection;

				return info.ConnectionString;
			}
		}

		public void Save()
		{
			SetParameterValue("database", this.Database);
			SetParameterValue("server", this.Server);
			
			if (this.UseTrustedConnection == true)
			{
				SetParameterValue("Integrated Security", "true");
				SetParameterValue("user id", null);
				SetParameterValue("password", null);
			}
			else
			{
				SetParameterValue("Integrated Security", "false");
				SetParameterValue("user id", this.UserName);
				SetParameterValue("password", this.Password);
			}

			base.Save();
		}
	}
}
