using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.Text;
using Com.Benday.Common;

/* 
   | Copyright 2007                |
   | Benjamin Day                  |
   | Benjamin Day Consulting, Inc. |
   | http://www.benday.com         |
   | http://blog.benday.com        |
    */

namespace Com.Benday.SqlServerUtility.UI
{
	/// <summary>
	/// Summary description for OracleConnStringBuilder.
	/// </summary>
	public class SqlServerConnStringBuilder : System.Windows.Forms.UserControl
	{
		private System.Windows.Forms.Panel m_panelLabels;
		private System.Windows.Forms.Panel m_panelTextboxes;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.TextBox m_textUID;
		private System.Windows.Forms.TextBox m_textPWD;
		private System.Windows.Forms.TextBox m_textServer;
		private System.Windows.Forms.TextBox m_textDatabaseName;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.CheckBox m_chkIsIntegratedSecurity;
		/// <summary> 
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;

		private DbConnectionInfo m_databaseConnection=new DbConnectionInfo();

		public SqlServerConnStringBuilder()
		{
			// This call is required by the Windows.Forms Form Designer.
			InitializeComponent();

			// TODO: Add any initialization after the InitializeComponent call

		}

		/// <summary> 
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		public string Server
		{
			get
			{
				return m_textServer.Text;
			}
		}

		public string Username
		{
			get
			{
				return m_textUID.Text;
			}
		}

		public string Database
		{
			get
			{
				return m_textDatabaseName.Text;
			}
		}


		public string Password
		{
			get
			{
				return m_textPWD.Text;
			}
		}

		public bool IsUsingIntegratedSecurity
		{
			get
			{
				return  m_chkIsIntegratedSecurity.Checked;
			}
			set
			{
				m_chkIsIntegratedSecurity.Checked=value;
			}
		}



		
		public string ConnectionString
		{
			get
			{
				m_databaseConnection.DatabaseType = DatabaseTypeEnum.SqlServer2000;
				m_databaseConnection.InitialCatalog = m_textDatabaseName.Text;
				m_databaseConnection.Password = m_textPWD.Text;
				m_databaseConnection.UserName = m_textUID.Text;

				if (m_textServer.Text.StartsWith("localhost") == true)
				{
					m_textServer.Text = m_textServer.Text.Replace("localhost", "(local)");
				}

				m_databaseConnection.ServerName = m_textServer.Text;


				m_databaseConnection.UseIntegratedSecurity = m_chkIsIntegratedSecurity.Checked;

				return m_databaseConnection.ConnectionString;
			}
			set
			{
				m_databaseConnection.ConnectionString = value;

				m_textDatabaseName.Text = m_databaseConnection.InitialCatalog;
				m_textPWD.Text = m_databaseConnection.Password;
				m_textUID.Text = m_databaseConnection.UserName;
				m_textServer.Text = m_databaseConnection.ServerName;
				m_chkIsIntegratedSecurity.Checked = m_databaseConnection.UseIntegratedSecurity;

				SetEnabledDisabled();
			}
		}

		private void SetEnabledDisabled()
		{
			if (m_chkIsIntegratedSecurity.Checked==true)
			{
				m_textUID.Enabled=false;
				m_textPWD.Enabled=false;
			}
			else
			{
				m_textUID.Enabled=true;
				m_textPWD.Enabled=true;
			}
		}

		#region Component Designer generated code
		/// <summary> 
		/// Required method for Designer support - do not modify 
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.m_panelLabels = new System.Windows.Forms.Panel();
			this.label4 = new System.Windows.Forms.Label();
			this.label3 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.label1 = new System.Windows.Forms.Label();
			this.m_panelTextboxes = new System.Windows.Forms.Panel();
			this.m_chkIsIntegratedSecurity = new System.Windows.Forms.CheckBox();
			this.m_textDatabaseName = new System.Windows.Forms.TextBox();
			this.m_textPWD = new System.Windows.Forms.TextBox();
			this.m_textUID = new System.Windows.Forms.TextBox();
			this.m_textServer = new System.Windows.Forms.TextBox();
			this.m_panelLabels.SuspendLayout();
			this.m_panelTextboxes.SuspendLayout();
			this.SuspendLayout();
			// 
			// m_panelLabels
			// 
			this.m_panelLabels.Controls.Add(this.label4);
			this.m_panelLabels.Controls.Add(this.label3);
			this.m_panelLabels.Controls.Add(this.label2);
			this.m_panelLabels.Controls.Add(this.label1);
			this.m_panelLabels.Dock = System.Windows.Forms.DockStyle.Left;
			this.m_panelLabels.Location = new System.Drawing.Point(0, 0);
			this.m_panelLabels.Name = "m_panelLabels";
			this.m_panelLabels.Size = new System.Drawing.Size(112, 224);
			this.m_panelLabels.TabIndex = 0;
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(8, 80);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(100, 23);
			this.label4.TabIndex = 3;
			this.label4.Text = "Database";
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(8, 56);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(100, 23);
			this.label3.TabIndex = 2;
			this.label3.Text = "Password";
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(8, 32);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(100, 23);
			this.label2.TabIndex = 1;
			this.label2.Text = "User Name";
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 8);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(100, 23);
			this.label1.TabIndex = 0;
			this.label1.Text = "Server";
			// 
			// m_panelTextboxes
			// 
			this.m_panelTextboxes.Controls.Add(this.m_chkIsIntegratedSecurity);
			this.m_panelTextboxes.Controls.Add(this.m_textDatabaseName);
			this.m_panelTextboxes.Controls.Add(this.m_textPWD);
			this.m_panelTextboxes.Controls.Add(this.m_textUID);
			this.m_panelTextboxes.Controls.Add(this.m_textServer);
			this.m_panelTextboxes.Dock = System.Windows.Forms.DockStyle.Fill;
			this.m_panelTextboxes.Location = new System.Drawing.Point(112, 0);
			this.m_panelTextboxes.Name = "m_panelTextboxes";
			this.m_panelTextboxes.Size = new System.Drawing.Size(248, 224);
			this.m_panelTextboxes.TabIndex = 1;
			this.m_panelTextboxes.Paint += new System.Windows.Forms.PaintEventHandler(this.m_panelTextboxes_Paint);
			// 
			// m_chkIsIntegratedSecurity
			// 
			this.m_chkIsIntegratedSecurity.Location = new System.Drawing.Point(16, 104);
			this.m_chkIsIntegratedSecurity.Name = "m_chkIsIntegratedSecurity";
			this.m_chkIsIntegratedSecurity.Size = new System.Drawing.Size(216, 24);
			this.m_chkIsIntegratedSecurity.TabIndex = 4;
			this.m_chkIsIntegratedSecurity.Text = "Use Integrated Security";
			this.m_chkIsIntegratedSecurity.CheckedChanged += new System.EventHandler(this.m_chkIsIntegratedSecurity_CheckedChanged);
			// 
			// m_textDatabaseName
			// 
			this.m_textDatabaseName.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.m_textDatabaseName.Location = new System.Drawing.Point(8, 80);
			this.m_textDatabaseName.Name = "m_textDatabaseName";
			this.m_textDatabaseName.Size = new System.Drawing.Size(232, 20);
			this.m_textDatabaseName.TabIndex = 3;
			// 
			// m_textPWD
			// 
			this.m_textPWD.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.m_textPWD.Location = new System.Drawing.Point(8, 56);
			this.m_textPWD.Name = "m_textPWD";
			this.m_textPWD.Size = new System.Drawing.Size(232, 20);
			this.m_textPWD.TabIndex = 2;
			// 
			// m_textUID
			// 
			this.m_textUID.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.m_textUID.Location = new System.Drawing.Point(8, 32);
			this.m_textUID.Name = "m_textUID";
			this.m_textUID.Size = new System.Drawing.Size(232, 20);
			this.m_textUID.TabIndex = 1;
			// 
			// m_textServer
			// 
			this.m_textServer.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
						| System.Windows.Forms.AnchorStyles.Right)));
			this.m_textServer.Location = new System.Drawing.Point(8, 8);
			this.m_textServer.Name = "m_textServer";
			this.m_textServer.Size = new System.Drawing.Size(232, 20);
			this.m_textServer.TabIndex = 0;
			// 
			// SqlServerConnStringBuilder
			// 
			this.Controls.Add(this.m_panelTextboxes);
			this.Controls.Add(this.m_panelLabels);
			this.Name = "SqlServerConnStringBuilder";
			this.Size = new System.Drawing.Size(360, 224);
			this.m_panelLabels.ResumeLayout(false);
			this.m_panelTextboxes.ResumeLayout(false);
			this.m_panelTextboxes.PerformLayout();
			this.ResumeLayout(false);

		}
		#endregion

		private void m_panelTextboxes_Paint(object sender, System.Windows.Forms.PaintEventArgs e)
		{
		
		}

		private void m_chkIsIntegratedSecurity_CheckedChanged(object sender, System.EventArgs e)
		{
			SetEnabledDisabled();
		}
	}
}
