using System;
using System.Collections.Generic;
using System.Text;
using Com.Benday.Common;
using System.Xml;

/* 
   | Copyright 2007                |
   | Benjamin Day                  |
   | Benjamin Day Consulting, Inc. |
   | http://www.benday.com         |
   | http://blog.benday.com        |
    */

namespace Com.Benday.InstallerActions
{
	public class HibernateDatabaseConfigurationParser : XmlConfigurationParserBase
	{
		public HibernateDatabaseConfigurationParser(string path) : base(path)
		{
			NamespaceManager.AddNamespace("default", "urn:nhibernate-configuration-2.2");
			PopulateValuesFromFile();
		}

		private void PopulateValuesFromFile()
		{
			// <property 
			// name="connection.connection_string"
			// >Server=.;initial catalog=FidelitySAI;User ID=sa;Password=sa_password;</property>

			string connStr = GetPropertyValue("connection.connection_string");

			DbConnectionInfo info = new DbConnectionInfo();
			info.ConnectionString = connStr;

			m_database = info.InitialCatalog;
			m_useTrustedConnection = info.UseIntegratedSecurity;
			m_server = info.ServerName;
			m_userName = info.UserName;
			m_password = info.Password;
		}

		private string GetPropertyValue(string propertyName)
		{
			XmlElement propertyElement = Document.DocumentElement.SelectSingleNode(
				String.Format(
				"//default:session-factory/default:property[@name='{0}']", propertyName), NamespaceManager) as XmlElement;

			if (propertyElement == null)
			{
				return null;
			}
			else
			{
				return propertyElement.InnerText;
			}
		}

		private void SetParameterValue(string propertyName, string propertyValue)
		{
			XmlElement sessionFactoryElement = Document.DocumentElement.SelectSingleNode(
				"//default:session-factory", NamespaceManager) as XmlElement;

			if (sessionFactoryElement == null)
			{
				throw new InvalidOperationException("Could not find parameters node.");
			}

			XmlElement propertyElement = sessionFactoryElement.SelectSingleNode(
				String.Format(
				"//default:property[@name='{0}']", propertyName), NamespaceManager) as XmlElement;

			if (propertyElement == null)
			{
				propertyElement = Document.CreateElement("property");
				propertyElement.Value = propertyValue;
				sessionFactoryElement.AppendChild(propertyElement);
			}
			else
			{
				if (propertyValue == null)
				{
					propertyElement.ParentNode.RemoveChild(propertyElement);
				}
				else
				{
					propertyElement.InnerText = propertyValue;
				}
			}
		}

		private string m_server;
		public string Server
		{
			get
			{
				return m_server;
			}
			set
			{
				m_server = value;
			}
		}

		private string m_userName;
		public string UserName
		{
			get
			{
				return m_userName;
			}
			set
			{
				m_userName = value;
			}
		}
		private string m_password;
		public string Password
		{
			get
			{
				return m_password;
			}
			set
			{
				m_password = value;
			}
		}

		private string m_database;
		public string Database
		{
			get
			{
				return m_database;
			}
			set
			{
				m_database = value;
			}
		}

		private bool m_useTrustedConnection;
		public bool UseTrustedConnection
		{
			get
			{
				return m_useTrustedConnection;
			}
			set
			{
				m_useTrustedConnection = value;
			}
		}

		public string ConnectionString
		{
			get
			{
				DbConnectionInfo info = new DbConnectionInfo();

				info.DatabaseType = DatabaseTypeEnum.SqlServer2000;

				info.InitialCatalog = this.Database;
				info.ServerName = this.Server;
				info.UserName = this.UserName;
				info.Password = this.Password;
				info.UseIntegratedSecurity = this.UseTrustedConnection;

				return info.ConnectionString;
			}
		}

		public void Save()
		{
			DbConnectionInfo info = new DbConnectionInfo();

			info.InitialCatalog = m_database;
			info.UseIntegratedSecurity = m_useTrustedConnection;
			info.ServerName = m_server;
			info.UserName = m_userName;
			info.Password = m_password;

			SetParameterValue("connection.connection_string", info.ConnectionString);

			base.Save();
		}
	}
}
