using System;
using System.Collections.Generic;
using System.Text;
using System.DirectoryServices;
using System.Collections.Specialized;
using System.Runtime.InteropServices;

/* 
   | Copyright 2007                |
   | Benjamin Day                  |
   | Benjamin Day Consulting, Inc. |
   | http://www.benday.com         |
   | http://blog.benday.com        |
    */

namespace Com.Benday.InstallerActions
{
	public sealed class IISActiveDirectoryUtility
	{
		private IISActiveDirectoryUtility()
		{

		}

		public static void SetSecurity(StringDictionary parameters)
		{
			DirectoryEntry targetVirtualDirectory = IISActiveDirectoryUtility.FindVirtualDirectory(parameters);

			int securityType = IISActiveDirectoryUtility.GetSecuritySetting(parameters);

			targetVirtualDirectory.Properties["AuthFlags"][0] = securityType;

			targetVirtualDirectory.CommitChanges();
		}

		public static int GetSecuritySetting(StringDictionary parameters)
		{
			string allowAnonymous = parameters["AllowAnonymous"];
			string allowBasic = parameters["AllowBasic"];
			string allowNTLM = parameters["AllowNTLM"];

			int securityType = 0;

			if (allowAnonymous == "1")
			{
				securityType = (securityType | SecuritySettingAllowAnonymous);
			}

			if (allowBasic == "1")
			{
				securityType = (securityType | SecuritySettingAllowBasic);
			}

			if (allowNTLM == "1")
			{
				securityType = (securityType | SecuritySettingAllowNTLM);
			}
			return securityType;
		}

		public const int SecuritySettingAllowAnonymous = 1;
		public const int SecuritySettingAllowBasic = 2;
		public const int SecuritySettingAllowNTLM = 4;

		public static string GetName(DirectoryEntry entryForDirectory)
		{
			if (entryForDirectory == null)
			{
				return null;
			}
			else
			{
				return entryForDirectory.Name;
			}
		}

		public static DirectoryEntry FindVirtualDirectory(StringDictionary parameters)
		{
			string targetVirtualDirectoryName = parameters["virtualDirectory"];

			if (targetVirtualDirectoryName == null)
			{
				throw new ArgumentNullException("targetVirtualDirectoryName", "Argument cannot be null.");
			}

			return FindDirectoryForPath(targetVirtualDirectoryName);
		}

		public static DirectoryEntry FindDirectoryForPath(string appDirectory)
		{
			string machineName = System.Environment.MachineName;
			string query;

			query = String.Format("IIS://{0}/w3svc", machineName);

			DirectoryEntry w3svc = new DirectoryEntry(query);

			DirectoryEntry appDirectoryEntry = null;

			foreach (DirectoryEntry webSite in w3svc.Children)
			{
				query = String.Format(
					"IIS://{0}/W3SVC/{1}/ROOT/{2}",
					machineName, webSite.Name, appDirectory);

				try
				{
					appDirectoryEntry = new DirectoryEntry(query);

					if (appDirectoryEntry != null)
					{
						appDirectoryEntry.RefreshCache();
						return appDirectoryEntry;
					}
				}
				catch (COMException)
				{

				}
				catch (Exception)
				{
					// not this one
				}
			}

			// couldn't find anything
			return null;
		}
	}
}
