using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using Com.Benday.Common;

/* 
   | Copyright 2007                |
   | Benjamin Day                  |
   | Benjamin Day Consulting, Inc. |
   | http://www.benday.com         |
   | http://blog.benday.com        |
    */

namespace Com.Benday.InstallerActions
{
	public class WebConfigConnectionStringParser : XmlConfigurationParserBase
	{
		private string m_connectionName;

		public WebConfigConnectionStringParser(string path, string connectionName)
			: base(path)
		{
			m_connectionName = connectionName; PopulateValuesFromFile();
		}

		private void PopulateValuesFromFile()
		{
			// <property 
			// name="connection.connection_string"
			// >Server=.;initial catalog=FidelitySAI;User ID=sa;Password=sa_password;</property>

			string connStr = GetConnectionString(m_connectionName);

			DbConnectionInfo info = new DbConnectionInfo();
			info.ConnectionString = connStr;

			m_database = info.InitialCatalog;
			m_useTrustedConnection = info.UseIntegratedSecurity;
			m_server = info.ServerName;
			m_userName = info.UserName;
			m_password = info.Password;
		}

		public string GetConnectionString(string name)
		{
			// appSettings
			XmlElement connectionStrings = Document.DocumentElement.SelectSingleNode("//connectionStrings") as XmlElement;

			//			<add name="WebConfigConnectionString"
			//            connectionString="Server=(local);initial catalog=TestDatabase;User ID=sa;Password=Password;"
			//            providerName="System.Data.SqlClient" />
			//

			if (connectionStrings == null)
			{
				throw new ArgumentNullException("connectionStrings", "Argument cannot be null.");
			}

			XmlElement setting = connectionStrings.SelectSingleNode(String.Format("./add[@name='{0}']", name)) as XmlElement;

			if (setting == null)
			{
				return null;
			}
			else
			{
				return setting.GetAttribute("connectionString");
			}
		}

		private void SetConnectionString(string name, string value)
		{
			// appSettings
			XmlElement connectionStrings = Document.DocumentElement.SelectSingleNode("//connectionStrings") as XmlElement;

//			<add name="WebConfigConnectionString"
//            connectionString="Server=(local);initial catalog=TestDatabase;User ID=sa;Password=Password;"
//            providerName="System.Data.SqlClient" />
//
			if (connectionStrings == null)
			{
				throw new ArgumentNullException("connectionStrings", "Argument cannot be null.");
			}

			XmlElement setting = connectionStrings.SelectSingleNode(String.Format("./add[@name='{0}']", name)) as XmlElement;

			if (setting == null)
			{
				if (value != null)
				{
					setting = Document.CreateElement("add");
					setting.SetAttribute("name", name);
					setting.SetAttribute("connectionString", value);
					setting.SetAttribute("providerName", "System.Data.SqlClient");
				}
			}
			else
			{
				if (value == null)
				{
					connectionStrings.RemoveChild(setting);
				}
				else
				{
					setting.SetAttribute("connectionString", value);
				}

			}
		}
		private string m_server;
		public string Server
		{
			get
			{
				return m_server;
			}
			set
			{
				if (value == "localhost" || value == ".")
				{
					m_server = "(local)";
				}
				else
				{
					m_server = value;
				}
			}
		}

		private string m_userName;
		public string UserName
		{
			get
			{
				return m_userName;
			}
			set
			{
				m_userName = value;
			}
		}
		private string m_password;
		public string Password
		{
			get
			{
				return m_password;
			}
			set
			{
				m_password = value;
			}
		}

		private string m_database;
		public string Database
		{
			get
			{
				return m_database;
			}
			set
			{
				m_database = value;
			}
		}

		private bool m_useTrustedConnection;
		public bool UseTrustedConnection
		{
			get
			{
				return m_useTrustedConnection;
			}
			set
			{
				m_useTrustedConnection = value;
			}
		}

		public string ConnectionString
		{
			get
			{
				DbConnectionInfo info = new DbConnectionInfo();

				info.DatabaseType = DatabaseTypeEnum.SqlServer2000;

				info.InitialCatalog = this.Database;
				info.ServerName = this.Server;
				info.UserName = this.UserName;
				info.Password = this.Password;
				info.UseIntegratedSecurity = this.UseTrustedConnection;

				return info.ConnectionString;
			}
		}

		public void Save()
		{
			DbConnectionInfo info = new DbConnectionInfo();

			info.InitialCatalog = m_database;
			info.UseIntegratedSecurity = m_useTrustedConnection;
			info.ServerName = m_server;
			info.UserName = m_userName;
			info.Password = m_password;

			SetConnectionString(m_connectionName, info.ConnectionString);

			base.Save();
		}
	}
}