using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;

/* 
   | Copyright 2007                |
   | Benjamin Day                  |
   | Benjamin Day Consulting, Inc. |
   | http://www.benday.com         |
   | http://blog.benday.com        |
    */

namespace Com.Benday.InstallerActions
{
	public class WebConfigParser : XmlConfigurationParserBase
	{
		public WebConfigParser(string path) : base(path)
		{

		}

		public string GetAppSetting(string name)
		{
			// appSettings
			XmlElement appSettings = Document.DocumentElement.SelectSingleNode("//appSettings") as XmlElement;

			if (appSettings == null)
			{
				throw new ArgumentNullException("appSettings", "Argument cannot be null.");
			}

			XmlElement setting = appSettings.SelectSingleNode(String.Format("./add[@key='{0}']", name)) as XmlElement;

			if (setting == null)
			{
				return null;
			}
			else
			{
				return setting.GetAttribute("value");
			}
		}

		private void SetAppSetting(string key, string value)
		{
			// appSettings
			XmlElement appSettings = Document.DocumentElement.SelectSingleNode("//appSettings") as XmlElement;

			if (appSettings == null)
			{
				throw new ArgumentNullException("appSettings", "Argument cannot be null.");
			}

			XmlElement setting = appSettings.SelectSingleNode(String.Format("./add[@key='{0}']", key)) as XmlElement;

			if (setting == null)
			{
				if (value != null)
				{
					setting = Document.CreateElement("add");
					setting.SetAttribute("key", key);
					setting.SetAttribute("value", value);
				}				
			}
			else
			{
				if (value == null)
				{
					appSettings.RemoveChild(setting);
				}
				else
				{
					setting.SetAttribute("value", value);
				}
				
			}
		}


		/// <summary>
		/// Get/Set application settings in web.config
		/// </summary>
		/// <param name="name"></param>
		/// <returns></returns>
		public string this[string name]
		{
			get 
			{
				return GetAppSetting(name);
			}
			set
			{
				SetAppSetting(name, value);
			}
		}

		
		
	
	}
}
